@@ -121,7 +121,7 @@
 #define HAVE_LIBCRYPT 1
 /* #undef HAVE_LIBMTMALLOC */
 /* #undef HAVE_LIBWRAP */
-/* #undef HAVE_SYSTEMD */
+#define HAVE_SYSTEMD 1
 /* Does "struct timespec" have a "sec" and "nsec" field? */
 /* #undef HAVE_TIMESPEC_TS_SEC */
 
@@ -641,16 +641,16 @@
 
 #define MYSQL_VERSION_MAJOR 10
 #define MYSQL_VERSION_MINOR 1
-#define MYSQL_VERSION_PATCH 14
+#define MYSQL_VERSION_PATCH 19
 #define MYSQL_VERSION_EXTRA ""
 
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 10.1.14"
+#define PACKAGE_STRING "MySQL Server 10.1.19"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "10.1.14"
-#define VERSION "10.1.14"
+#define PACKAGE_VERSION "10.1.19"
+#define VERSION "10.1.19"
 #define PROTOCOL_VERSION 10
 
 #define MALLOC_LIBRARY "system"
